==> deepin-boot-maker_1.1.2.orig.tar.xz: deepin-boot-maker-1.1.2/README.md <==
# Deepin Boot Maker

Deepin Boot Maker is a tool that helps user to create a bootable usb stick quick and easy, it is designed to support deepin install iso, but it works for all ubuntu live install iso too.

![screenshot](https://cloud.githubusercontent.com/assets/1117694/5467718/d3fcf2f4-85fe-11e4-9c6a-e64c2198b9c4.png)

## Dependencies

Deepin Boot Maker is designed to support Windows/Linux/Mac platforms. It has no external dependencies on Windows and Mac OS. On Linux, you need packages below:

```bash
#For release based on debian
sudo apt-get install  p7zip-full mtools
```

Official support platform:

- Deepin 2014/2015

- Mac OSX 10.10

- Windows XP 32/64bit, Windows 7 32/64bit, Windows 8 32/64 bit.

## Installation

- Official binary release

The only binary release is from Deepin OS iso for now. You can download iso from: http://www.deepin.org/download.html. You can find binary file on the root of iso.

- Repository Install

If you are deepin user, you can install Deepin Boot Maker from repository:

```bash
sudo apt-get install deepin-boot-maker
```

- Build and install

See [INSTALL](INSTALL.md) for detail.

## Getting help

Any usage issues can ask for help via

* [Gitter](https://gitter.im/orgs/linuxdeepin/rooms)
* [IRC channel](https://webchat.freenode.net/?channels=deepin)
* [Forum](https://bbs.deepin.org)
* [WiKi](http://wiki.deepin.org/)

## Getting involved

We encourage you to report issues and contribute changes

* [Contribution guide for users](http://wiki.deepin.org/index.php?title=Contribution_Guidelines_for_Users)
* [Contribution guide for developers](http://wiki.deepin.org/index.php?title=Contribution_Guidelines_for_Developers).

## License

Deepin Boot Maker is licensed under [GPLv3](LICENSE).

## Credits and references

1. [UNetbootin](https://github.com/unetbootin/unetbootin): this projects is derived form unetbootin, but now there are big differences between them.

==> deepin-boot-maker_1.9.0.orig.tar.xz: deepin-boot-maker-1.9.0/README.md <==
# Deepin Boot Maker

Deepin Boot Maker is a tool that helps user to create a bootable usb stick quick and easy, it is designed to support deepin install iso, but it works for all ubuntu live install iso too.

![screenshot](https://cloud.githubusercontent.com/assets/1117694/5467718/d3fcf2f4-85fe-11e4-9c6a-e64c2198b9c4.png)

## Dependencies

Deepin Boot Maker is designed to support Windows/Linux/Mac platforms. It has no external dependencies on Windows and Mac OS. On Linux, you need packages below:

```bash
#For release based on debian
sudo apt-get install  p7zip-full mtools
```

Official support platform:

- Deepin 2014/2015

- Mac OSX 10.10

- Windows XP 32/64bit, Windows 7 32/64bit, Windows 8 32/64 bit.

## Installation

- Official binary release

The only binary release is from Deepin OS iso for now. You can download iso from: http://www.deepin.org/download.html. You can find binary file on the root of iso.

- Repository Install

If you are deepin user, you can install Deepin Boot Maker from repository:

```bash
sudo apt-get install deepin-boot-maker
```

- Build and install

See [INSTALL](INSTALL.md) for detail.

## Getting help

Any usage issues can ask for help via

* [Gitter](https://gitter.im/orgs/linuxdeepin/rooms)
* [IRC channel](https://webchat.freenode.net/?channels=deepin)
* [Forum](https://bbs.deepin.org)
* [WiKi](http://wiki.deepin.org/)

## Getting involved

We encourage you to report issues and contribute changes

* [Contribution guide for users.](http://wiki.deepin.org/index.php?title=Contribution_Guidelines_for_Users)
* [Contribution guide for developers.](http://wiki.deepin.org/index.php?title=Contribution_Guidelines_for_Developers).

## License

Deepin Boot Maker is licensed under [GPLv3](LICENSE).

## Credits and references

1. [UNetbootin](https://github.com/unetbootin/unetbootin): this projects is derived form unetbootin, but now there are big differences between them.
